package	jp.co.sds_corp.util.daemon.remote.socket;

import java.net.InetAddress;

/**
* クライアントのIPアドレスの情報を保持します。
*/
public class Restrict
{
	String	from;	// クライアントのIPアドレス
	boolean	allow;	// このアドレスを許可するか
	int type;

	/**
	* @param	from	クライアントのIPアドレス
	* @param	allow	このアドレスを許可するか
	*/
	public Restrict( String from, boolean allow ) {
		this.from = from;
		this.allow = allow;
		if ( from.charAt( from.length() - 1 ) == '.' ) {
			type = 1;
		} else
		if ( from.charAt( 0 ) == '.' ) {
			type = 2;
		} else {
			type = 0;
		}
	}

	/**
	* この条件に合致しているかチェックする
	* @param	addr	チェックするアドレス
	*/
	public boolean match( InetAddress addr ) {
		boolean bRet = false;
		switch ( type ) {
		case 0:
			if (( addr.getHostName() != null &&
				addr.getHostName().equals( from )) ||
				addr.getHostAddress().equals( from ))
			{
				bRet = true;
			}
			break;
		case 1:
			if (( addr.getHostName() != null &&
				addr.getHostName().startsWith( from )) ||
				addr.getHostAddress().startsWith( from ))
			{
				bRet = true;
			}
			break;
		case 2:
			if (( addr.getHostName() != null &&
				addr.getHostName().endsWith( from )) ||
				addr.getHostAddress().endsWith( from ))
			{
				bRet = true;
			}
			break;
		}
		return bRet;
	}

	/**
	* クライアントのIPアドレスを設定します。
	* @param	var		設定するデータ
	*/
	public void setFrom( String var ) {
		this.from = var;
	}
	/**
	* クライアントのIPアドレスを取得します。
	* @return	クライアントのIPアドレス
	*/
	public String getFrom() {
		return from;
	}

	/**
	* このアドレスを許可するかを設定します。
	* @param	var		設定するデータ
	*/
	public void setAllow( boolean var ) {
		this.allow = var;
	}
	/**
	* このアドレスを許可するかを取得します。
	* @return	このアドレスを許可するか
	*/
	public boolean isAllow() {
		return allow;
	}


}
